﻿using Syncfusion.HtmlConverter;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Xml.Linq;

namespace SVGtoPDF_PageSize
{
    class Program
    {
        static string width = string.Empty;
        static string height = string.Empty;
        static void Main(string[] args)
        {
            string svgurl = System.IO.Path.GetFullPath("../../Data/sampleSho.svg");
            XDocument svgDoc = XDocument.Load(svgurl);
            bool widthfound = false;
            bool heightfound = false;
            foreach (var attribute in svgDoc.Elements().Attributes())
            {
                if (attribute.Name != null && attribute.Name == "width")
                {
                    width = attribute.Value;
                    widthfound = true;
                }
                if (attribute.Name != null && attribute.Name == "height")
                {
                    height = attribute.Value;
                    heightfound = true;
                }
                if (widthfound && heightfound)
                    break;
            }

            //Initialize HTML to PDF converter 
            HtmlToPdfConverter htmlConverter = new HtmlToPdfConverter(HtmlRenderingEngine.WebKit);

            WebKitConverterSettings settings = new WebKitConverterSettings();

            //set the pdf page size based on the svg size. 
            System.Drawing.SizeF pagesize = SetPageSizeFromSvgSize();

            //Change the orientation if the  page width is greater than the height
            if (pagesize.Width > pagesize.Height)
                settings.Orientation = PdfPageOrientation.Landscape;

            settings.PdfPageSize = pagesize;

            //Set WebKit viewport size. 
            settings.WebKitViewPort = new System.Drawing.Size((int)pagesize.Width, 0);

            //Set WebKit path
            settings.WebKitPath = System.IO.Path.GetFullPath("../../QtBinaries/");

            //Assign WebKit settings to HTML converter
            htmlConverter.ConverterSettings = settings;

            //Convert URL to PDF
            PdfDocument document = htmlConverter.Convert(svgurl);


            //Save and close the PDF document 
            document.Save("SVGtoPDF.pdf");

            document.Close(true);

            System.Diagnostics.Process.Start("SVGtoPDF.pdf");
        }

        private static System.Drawing.SizeF SetPageSizeFromSvgSize()
        {
            float widthVal = 0;
            float heightVal = 0;

            PdfUnitConvertor converter = new PdfUnitConvertor();

            if (width.Contains("mm"))
            {
                widthVal = float.Parse(width.Substring(0, width.Length - 2));
                widthVal = converter.ConvertUnits(widthVal, PdfGraphicsUnit.Millimeter, PdfGraphicsUnit.Point);
            }
            else if (width.Contains("px"))
            {
                widthVal = float.Parse(width.Substring(0, width.Length - 2));
                widthVal = converter.ConvertFromPixels(widthVal, PdfGraphicsUnit.Point);
            }
            else
            {
                widthVal = float.Parse(width);
                widthVal = converter.ConvertFromPixels(widthVal, PdfGraphicsUnit.Point);
            }

            if (height.Contains("mm"))
            {
                heightVal = float.Parse(height.Substring(0, height.Length - 2));
                heightVal = converter.ConvertUnits(heightVal, PdfGraphicsUnit.Millimeter, PdfGraphicsUnit.Point);
            }
            else if(height.Contains("px"))
            {
                heightVal = float.Parse(height.Substring(0, height.Length - 2));
                heightVal = converter.ConvertFromPixels(heightVal, PdfGraphicsUnit.Point);
            }
            else
            {
                heightVal = float.Parse(height);
                heightVal = converter.ConvertFromPixels(heightVal, PdfGraphicsUnit.Point);
            }


            //set default size, if no width or height found in the svg. 
            if (widthVal <= 0)
                widthVal = PdfPageSize.A4.Width;
            if (heightVal <= 0)
                heightVal = PdfPageSize.A4.Height;

            //Create size based on the svg width and height.
            return new System.Drawing.SizeF(widthVal, heightVal);
        }
    }
}
